aboutsummaryrefslogtreecommitdiffstats
path: root/src
diff options
context:
space:
mode:
authorMartin Willi <martin@strongswan.org>2008-03-28 12:44:01 +0000
committerMartin Willi <martin@strongswan.org>2008-03-28 12:44:01 +0000
commit6b9290ff120fbe31d9926cc49701aa3068248e0a (patch)
treeb64b2bed0a689ed8cd73210a61dda46456097c64 /src
parent892fb43b12e33bc8a297f7fd527e11a14871ee8f (diff)
downloadstrongswan-6b9290ff120fbe31d9926cc49701aa3068248e0a.tar.bz2
strongswan-6b9290ff120fbe31d9926cc49701aa3068248e0a.tar.xz
renamed xml plugin to smp to avoid confusion
added some dependency checks to configure configure checks ClearSilver and fastcgi cleanups in the build system here and there
Diffstat (limited to 'src')
-rw-r--r--src/Makefile.am2
-rw-r--r--src/charon/Makefile.am28
-rw-r--r--src/charon/plugins/smp/Makefile.am10
-rw-r--r--src/charon/plugins/smp/schema.xml (renamed from src/charon/plugins/xml/schema.xml)0
-rw-r--r--src/charon/plugins/smp/smp.c (renamed from src/charon/plugins/xml/xml.c)18
-rw-r--r--src/charon/plugins/smp/smp.h (renamed from src/charon/plugins/xml/xml.h)20
-rw-r--r--src/charon/plugins/sql/sql_config.c2
-rw-r--r--src/charon/plugins/xml/Makefile.am10
-rw-r--r--src/pluto/Makefile.am5
-rw-r--r--src/scepclient/Makefile.am7
10 files changed, 61 insertions, 41 deletions
diff --git a/src/Makefile.am b/src/Makefile.am
index 504401230..66c2182e5 100644
--- a/src/Makefile.am
+++ b/src/Makefile.am
@@ -27,7 +27,7 @@ if USE_TOOLS
SUBDIRS += openac scepclient
endif
-if USE_UML
+if USE_DUMM
SUBDIRS += dumm
endif
diff --git a/src/charon/Makefile.am b/src/charon/Makefile.am
index 2ce3dfa34..886422a61 100644
--- a/src/charon/Makefile.am
+++ b/src/charon/Makefile.am
@@ -91,6 +91,14 @@ credentials/sets/ocsp_response_wrapper.c credentials/sets/ocsp_response_wrapper.
credentials/sets/cert_cache.c credentials/sets/cert_cache.h \
credentials/credential_set.h
+INCLUDES = -I${linuxdir} -I$(top_srcdir)/src/libstrongswan -I$(top_srcdir)/src/charon
+AM_CFLAGS = -rdynamic -DIPSEC_DIR=\"${ipsecdir}\" \
+ -DIPSEC_PIDDIR=\"${piddir}\" -DIPSEC_PLUGINDIR=\"${plugindir}\"
+charon_LDADD = $(top_builddir)/src/libstrongswan/libstrongswan.la -lpthread -lm -ldl
+
+# compile options
+#################
+
# Use RAW socket if pluto gets built
if USE_PLUTO
charon_SOURCES += network/socket-raw.c
@@ -99,6 +107,7 @@ else
endif
if USE_ME
+ AM_CFLAGS += -DME
charon_SOURCES += encoding/payloads/endpoint_notify.c encoding/payloads/endpoint_notify.h \
processing/jobs/initiate_mediation_job.c processing/jobs/initiate_mediation_job.h \
processing/jobs/mediation_job.c processing/jobs/mediation_job.h \
@@ -107,10 +116,13 @@ if USE_ME
sa/tasks/ike_me.c sa/tasks/ike_me.h
endif
-INCLUDES = -I${linuxdir} -I$(top_srcdir)/src/libstrongswan -I$(top_srcdir)/src/charon
-AM_CFLAGS = -rdynamic -DIPSEC_DIR=\"${ipsecdir}\" \
- -DIPSEC_PIDDIR=\"${piddir}\" -DIPSEC_PLUGINDIR=\"${plugindir}\"
-charon_LDADD = $(top_builddir)/src/libstrongswan/libstrongswan.la -lpthread -lm -ldl
+if USE_INTEGRITY_TEST
+ AM_CFLAGS += -DINTEGRITY_TEST
+endif
+
+if USE_SELF_TEST
+ AM_CFLAGS += -DSELF_TEST
+endif
# build optional plugins
########################
@@ -125,12 +137,8 @@ if USE_STROKE
SUBDIRS += plugins/stroke
endif
-if USE_LIBDBUS
- SUBDIRS += plugins/dbus
-endif
-
-if USE_LIBXML
- SUBDIRS += plugins/xml
+if USE_SMP
+ SUBDIRS += plugins/smp
endif
if USE_SQL
diff --git a/src/charon/plugins/smp/Makefile.am b/src/charon/plugins/smp/Makefile.am
new file mode 100644
index 000000000..b1b0e5ce0
--- /dev/null
+++ b/src/charon/plugins/smp/Makefile.am
@@ -0,0 +1,10 @@
+
+INCLUDES = -I$(top_srcdir)/src/libstrongswan -I$(top_srcdir)/src/charon ${xml_CFLAGS}
+
+AM_CFLAGS = -rdynamic -DIPSEC_PIDDIR=\"${piddir}\"
+
+plugin_LTLIBRARIES = libcharon-smp.la
+libcharon_smp_la_SOURCES = smp.h smp.c
+libcharon_smp_la_LDFLAGS = -module
+libcharon_smp_la_LIBADD = ${xml_LIBS}
+
diff --git a/src/charon/plugins/xml/schema.xml b/src/charon/plugins/smp/schema.xml
index 66a51117e..66a51117e 100644
--- a/src/charon/plugins/xml/schema.xml
+++ b/src/charon/plugins/smp/schema.xml
diff --git a/src/charon/plugins/sql/sql_config.c b/src/charon/plugins/sql/sql_config.c
index 1cc52ac8b..38c16b280 100644
--- a/src/charon/plugins/sql/sql_config.c
+++ b/src/charon/plugins/sql/sql_config.c
@@ -78,7 +78,7 @@ static traffic_selector_t *build_traffic_selector(private_sql_config_t *this,
*local = TRUE;
/* FALL */
case TS_REMOTE_DYNAMIC:
- ts = traffic_selector_create_dynamic(protocol, type,
+ ts = traffic_selector_create_dynamic(protocol,
start_port, end_port);
break;
default:
diff --git a/src/charon/plugins/xml/Makefile.am b/src/charon/plugins/xml/Makefile.am
deleted file mode 100644
index 0e4735a41..000000000
--- a/src/charon/plugins/xml/Makefile.am
+++ /dev/null
@@ -1,10 +0,0 @@
-
-INCLUDES = -I$(top_srcdir)/src/libstrongswan -I$(top_srcdir)/src/charon ${xml_CFLAGS}
-
-AM_CFLAGS = -rdynamic -DIPSEC_PIDDIR=\"${piddir}\"
-
-plugin_LTLIBRARIES = libcharon-xml.la
-libcharon_xml_la_SOURCES = xml.h xml.c
-libcharon_xml_la_LDFLAGS = -module
-libcharon_xml_la_LIBADD = ${xml_LIBS}
-
diff --git a/src/pluto/Makefile.am b/src/pluto/Makefile.am
index f7125b920..156b81018 100644
--- a/src/pluto/Makefile.am
+++ b/src/pluto/Makefile.am
@@ -134,3 +134,8 @@ if USE_LDAP
AM_CFLAGS += -DLIBLDAP
endif
+# This compile option activates smartcard support
+if USE_SMARTCARD
+ AM_CFLAGS += -DSMARTCARD
+endif
+
diff --git a/src/scepclient/Makefile.am b/src/scepclient/Makefile.am
index d1bce886d..57b20dfb5 100644
--- a/src/scepclient/Makefile.am
+++ b/src/scepclient/Makefile.am
@@ -25,9 +25,16 @@ scepclient_LDADD = asn1.o ca.o crl.o certs.o constants.o defs.o fetch.o id.o \
# This compile option activates smartcard support
if USE_SMARTCARD
+ AM_CFLAGS += -DSMARTCARD
scepclient_LDADD += -ldl
endif
+# This compile option activates dynamic URL fetching using libcurl
+if USE_CURL
+ AM_CFLAGS += -DLIBCURL
+ scepclient_LDADD += -lcurl
+endif
+
dist_man_MANS = scepclient.8
asn1.o : $(PLUTODIR)/asn1.c $(PLUTODIR)/asn1.h
diff --git a/src/charon/plugins/xml/xml.c b/src/charon/plugins/smp/smp.c
index 85778f608..959fb9a67 100644
--- a/src/charon/plugins/xml/xml.c
+++ b/src/charon/plugins/smp/smp.c
@@ -17,7 +17,7 @@
#include <stdlib.h>
-#include "xml.h"
+#include "smp.h"
#include <sys/types.h>
#include <sys/stat.h>
@@ -35,17 +35,17 @@
#include <processing/jobs/callback_job.h>
-typedef struct private_xml_t private_xml_t;
+typedef struct private_smp_t private_smp_t;
/**
* Private data of an xml_t object.
*/
-struct private_xml_t {
+struct private_smp_t {
/**
* Public part of xml_t object.
*/
- xml_t public;
+ smp_t public;
/**
* XML unix socket fd
@@ -662,7 +662,7 @@ static job_requeue_t process(int *fdp)
/**
* accept from XML socket and create jobs to process connections
*/
-static job_requeue_t dispatch(private_xml_t *this)
+static job_requeue_t dispatch(private_smp_t *this)
{
struct sockaddr_un strokeaddr;
int oldstate, fd, *fdp, strokeaddrlen = sizeof(strokeaddr);
@@ -691,7 +691,7 @@ static job_requeue_t dispatch(private_xml_t *this)
/**
* Implementation of itnerface_t.destroy.
*/
-static void destroy(private_xml_t *this)
+static void destroy(private_smp_t *this)
{
this->job->cancel(this->job);
close(this->socket);
@@ -704,7 +704,7 @@ static void destroy(private_xml_t *this)
plugin_t *plugin_create()
{
struct sockaddr_un unix_addr = { AF_UNIX, IPSEC_PIDDIR "/charon.xml"};
- private_xml_t *this = malloc_thing(private_xml_t);
+ private_smp_t *this = malloc_thing(private_smp_t);
mode_t old;
this->public.plugin.destroy = (void (*)(plugin_t*))destroy;
@@ -35,17 +35,17 @@
/**
- * Private data of an xml_t object.
+ * Private data of an smp_t object.
*/
@@ -35,17 +35,17 @@
/**
- * Public part of xml_t object.
+ * Public part of smp_t object.
*/
diff --git a/src/charon/plugins/xml/xml.h b/src/charon/plugins/smp/smp.h
index 289fca5f6..d8687d55c 100644
--- a/src/charon/plugins/xml/xml.h
+++ b/src/charon/plugins/smp/smp.h
@@ -16,27 +16,27 @@
*/
/**
- * @defgroup xml xml
+ * @defgroup smp smp
* @ingroup cplugins
*
- * @defgroup xml_i xml
- * @{ @ingroup xml
+ * @defgroup smp_i smp
+ * @{ @ingroup smp
*/
-#ifndef XML_H_
-#define XML_H_
+#ifndef SMP_H_
+#define SMP_H_
#include <plugins/plugin.h>
-typedef struct xml_t xml_t;
+typedef struct smp_t smp_t;
/**
* XML configuration and control interface.
*
* The XML interface uses a socket and a to communicate. The syntax is strict
* XML, defined in the schema.xml specification.
*/
-struct xml_t {
+struct smp_t {
/**
* implements the plugin interface.
@@ -45,7 +45,7 @@ struct xml_t {
};
/**
* Create a xml plugin instance.
*/
plugin_t *plugin_create();
@@ -16,27 +16,27 @@
/**
- * XML configuration and control interface.
+ * SMP configuration and control interface.
*
@@ -16,27 +16,27 @@
*
- * The XML interface uses a socket and a to communicate. The syntax is strict
+ * The SMP interface uses a socket and a to communicate. The syntax is strict
* XML, defined in the schema.xml specification.
*/
@@ -45,7 +45,7 @@ struct xml_t {
};
/**
- * Create a xml plugin instance.
+ * Create a smp plugin instance.
*/
plugin_t *plugin_create();